#
# CanDo - Web based competency tracking system.
# Copyright (C) 2006 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
"""
Unit tests for cando.generations.evolve9
"""
import unittest

from zope.app.testing import setup
from zope.testing import doctest
from zope.interface import implements
from zope.container import btree
from zope.container.contained import Contained

from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.course.interfaces import ICourse


class AppStub(btree.BTreeContainer):
    implements(ISchoolToolApplication)


class CourseStub(Contained):
    implements(ICourse)
    government_id = None

    def __repr__(self):
        return '<CourseStub(__name__="%s", government_id="%s")>' % (
            self.__name__, self.government_id)


def doctest_evolve9():
    """Evolution to generation 9.

        >>> from cando.generations.tests import ContextStub
        >>> context = ContextStub()
        >>> context.root_folder['app'] = app = AppStub()

    Let's set up some courses.

        >>> courses = app['courses'] = btree.BTreeContainer()
        >>> courses['c1'] = CourseStub()
        >>> courses['c2'] = CourseStub()
        >>> courses['c3'] = CourseStub()
        >>> courses['c3'].government_id = 'custom'
        >>> list(courses.values())
        [<CourseStub(__name__="c1", government_id="None")>,
         <CourseStub(__name__="c2", government_id="None")>,
         <CourseStub(__name__="c3", government_id="custom")>]

    Let's evolve now.

        >>> from cando.generations.evolve9 import evolve
        >>> evolve(context)

    Course government ids are updated.

        >>> list(courses.values())
        [<CourseStub(__name__="c1", government_id="c1")>,
         <CourseStub(__name__="c2", government_id="c2")>,
         <CourseStub(__name__="c3", government_id="custom")>]

    """


def setUp(test):
    setup.placelessSetUp()


def tearDown(test):
    setup.placelessTearDown()


def test_suite():
    optionflags = (doctest.ELLIPSIS |
                   doctest.NORMALIZE_WHITESPACE |
                   doctest.REPORT_ONLY_FIRST_FAILURE)
    return doctest.DocTestSuite(setUp=setUp, tearDown=tearDown,
                                optionflags=optionflags)


if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')
