#
# CanDo - Web based competency tracking system.
# Copyright (C) 2010 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
"""
Student IEP

$Id$
"""

import rwproperty
from persistent.dict import PersistentDict
from zope.annotation.interfaces import IAnnotations
from zope.component import adapts
from zope.i18nmessageid import MessageFactory
from zope.interface import implements
from zope.security.proxy import removeSecurityProxy

from schooltool.basicperson.interfaces import IBasicPerson
from schooltool.schoolyear.interfaces import ISchoolYear

from cando.iep import interfaces


IEP_KEY = "cando.iep"
_ = MessageFactory('cando')


class StudentIEP(object):
    """Individualized Educational Plan for a Student"""

    implements(interfaces.IStudentIEP)
    adapts(IBasicPerson)

    def __init__(self, context):
        self.context = removeSecurityProxy(context)
        annotations = IAnnotations(self.context)
        mapping = annotations.get(IEP_KEY)
        if mapping is None:
            blank = {'hasIEP': False, 'comment': None,
                     'competencies': PersistentDict({})}
            mapping = annotations[IEP_KEY] = PersistentDict(blank)
        self.mapping = mapping

    @rwproperty.getproperty
    def hasIEP(self):
        return self.mapping['hasIEP']

    @rwproperty.setproperty
    def hasIEP(self, value):
        self.mapping['hasIEP'] = value

    @rwproperty.getproperty
    def comment(self):
        return self.mapping['comment']

    @rwproperty.setproperty
    def comment(self, value):
        self.mapping['comment'] = value

    @rwproperty.getproperty
    def competencies(self):
        return self.mapping['competencies']

    @rwproperty.setproperty
    def competencies(self, value):
        self.mapping['competencies'] = value

    def isIEPCompetency(self, section, comp):
        school_year = ISchoolYear(section)
        school_year_name = school_year.__name__
        if school_year_name not in self.competencies:
            return False
        school_year_comps = self.competencies[school_year_name]
        if section.__name__ not in school_year_comps:
            return False
        return comp.globalId in school_year_comps[section.__name__]

    def getIEPCompetencies(self, section):
        school_year = ISchoolYear(section)
        school_year_name = school_year.__name__
        if school_year_name in self.competencies and \
           section.__name__ in self.competencies[school_year_name]:
            return self.competencies[school_year_name][section.__name__]
        return None
