#
# CanDo - Web based competency tracking system.
# Copyright (C) 2010 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
"""
IEP Interfaces

$Id$
"""

from zope.schema import Bool, TextLine, Text, Dict, List
from zope.interface import Interface

from zope.i18nmessageid import MessageFactory
_ = MessageFactory('cando')


class IStudentIEP(Interface):
    """Individualized Educational Plan for a Student.

    It stores a flag telling if the student has an IEP, an optional
    comment and a competencies dictionary with the following structure:

    competencies = {'school_year_1': {'1': ['comp1', 'comp2', 'comp3'],
                                      '2': ['comp4', 'comp5'],
                                      '3': ['comp6',]
                                      },
                    'school_year_2': {'1': ['comp10', 'comp11'],
                                      '2': []
                                      },
                    }

    'school_year_1' and 'school_year_2' are identifiers of ISchoolYear
    object (their __name__ attribute).

    The dictionaries of the second level store ISection identifiers as
    their key, and a list of globalId that represent IEP competencies
    for that section in that school year."""

    hasIEP = Bool(
        title = _(u"IEP"),
        description = _(u"Does the student have an Individualized "
                        u"Educational Plan?"),
        default = False)

    comment = Text(
        title = _(u"Comment"),
        description = _(u"Additional information for the IEP"),
        required = False)

    competencies = Dict(
        title = _(u"IEP School Years"),
        key_type = TextLine(
            title=_("School year identifier")
            ),
        value_type = Dict(
            title = _("IEP Sections"),
            key_type = TextLine(
                title = _("Section identifier")
                ),
            value_type = List(
                title=_("IEP Competencies globalIds"),
                value_type = TextLine(title=_("Competency globalId")),
                min_length = 0
                )
            ),
        required = False)
