#
# CanDo - Web based competency tracking system.
# Copyright (C) 2006 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
from zope.interface import implements
import zope.component
from zope.viewlet import manager, viewlet
from z3c.pagelet.browser import BrowserPagelet

from cando.newskin import interfaces, SectionChooser


class Go(BrowserPagelet):
    implements(interfaces.ISummaryView)

    def update(self):
        self.no_crumb_options = True


class EmptyBreadcrumbMenu(object):

    def __init__(self, context, request, view):
        self.context = context
        self.request = request
        self.view = view

    def update(self):
        pass

    def render(self):
        return ''

class SummaryManager(manager.ViewletManagerBase):
    implements(interfaces.ISummaryManager)

    def __getitem__(self, name):
        """See zope.interface.common.mapping.IReadMapping"""
        viewlet = super(SummaryManager, self).__getitem__(name)
        if not viewlet.isAvailable():
            raise zope.component.interfaces.ComponentLookupError(
                'Viewlet `%s` is not available.' %name)

    def filter(self, viewlets):
        """Filter by by availability."""
        viewlets = super(SummaryManager, self).filter(viewlets)
        return [(name, viewlet) for name, viewlet in viewlets
                if viewlet.isAvailable()]

    def sort(self, viewlets):
        """Sort the viewlets by weight."""
        return sorted(viewlets, key=lambda v: v[1].getWeight())

class SummaryViewlet(viewlet.ViewletBase):
    weight = 0

    def getWeight(self):
        """See interfaces.IDashboardCategory"""
        return int(self.weight)

    def isAvailable(self):
        return True

class SectionSummaryViewlet(SummaryViewlet, SectionChooser):
    """Presents navigation to different section related views."""

    weight = 100

