#
# CanDo - Web based competency tracking system.
# Copyright (C) 2006 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
"""
Virginia Gradebook views

$Id:$
"""
import zope.schema
from zope.publisher.browser import BrowserView
from zope.component import getMultiAdapter
from zope.security.proxy import removeSecurityProxy
from zope.traversing.browser import absoluteURL

from z3c.form import form, button
from z3c.formjs import ajax, jsaction
from z3c.formjs.interfaces import IRenderer

from schooltool.course.section import InstructorsCrowd, LearnersCrowd

from cando.message.interfaces import IMessageBox, ISectionMessageBox
from cando.queuing.interfaces import IQueueItem
from cando.queuing.queue import QueueItemOwnerCrowd

class QueueView(BrowserView):

    def __call__(self):
        self.context = removeSecurityProxy(self.context)
        
        return super(QueueView, self).__call__()

class IQueueItemStatusButtons(zope.interface.Interface):
    submit = jsaction.JSButton(title=u"Submit for Review")


class QueueItemStatus(ajax.AJAXRequestHandler, form.Form):
    """This view will return something meaningful only if the MessageBox it is in is a SectionMessageBox"""

    buttons = button.Buttons(IQueueItemStatusButtons)

    @jsaction.handler(buttons['submit'])
    def submitButtonJS(self, event, selector):
        url = absoluteURL(self.context, self.request) + '/@@queuestatus/@@ajax/submit?submit_queue=True'
        return '''$.get("%s", function(data){
                       $("#%s").html(data);
                  })''' % (url, self.prefix)

    @ajax.handler
    def submit(self):
        '''Handles ajax call for bumping queue status'''
        self.setup()
        if self.request.get('submit_queue'):
            if self.isStudent:
                if self.status is None or self.status=="processed":
                    self.queueItem.queue()
                    return "Submitted for review."
            if self.isInstructor:
                if self.status=="pending":
                    self.queueItem.queue()
                    return "Reviewed."
        return 'an error has occured'

    @property
    def prefix(self):
        context = self.context
        prefix = ""
        while not IMessageBox.providedBy(context):
            prefix += context.__name__
            context = context.__parent__
        return str(prefix)

    def setup(self):
        context = removeSecurityProxy(self.context)
        self.queueItem = IQueueItem(context)
        if self.queueItem.status:
            self.status, self.datetime = self.queueItem.status
        else:
            self.status, self.datetime = (None, None)
        
    def __call__(self):
        messagebox = removeSecurityProxy(self.context)
        while not IMessageBox.providedBy(messagebox):
            messagebox = messagebox.__parent__
        if not ISectionMessageBox.providedBy(messagebox):
            return ''
        self.update()
        self.setup()
        if not self.authorized :
            return ''
        
        submitAction = self.actions['submit']
        contents = ""

        if self.status == "pending":
            if self.isStudent:
                contents = "This message is awaiting teacher review "
                contents += u"it was submitted on %s" % self.datetime.strftime("%H:%M %D")                
            if self.isInstructor:
                submitAction.title = u"Mark message as reviewed"
                contents = u"Submitted on %s" % self.datetime.strftime("%H:%M %D")                
                contents += submitAction.render()
        if self.status == "processed":
            if self.isStudent:
                submitAction.title = u"Resubmit message for review"
                contents = u"Reviewed on %s" % self.datetime.strftime("%H:%M %D")                
                contents += submitAction.render()
            if self.isInstructor:
                contents = u"Reviewed on %s" % self.datetime.strftime("%H:%M %D")
        if self.status == None:
            if self.isStudent:
                submitAction.title = u"Submit message for review"
                contents = submitAction.render()#Submit message for review

        jsRenderer = getMultiAdapter((self.jsSubscriptions, self.request), IRenderer)
        jsRenderer.update()
        jsCode = '<script type="text/javascript">%s</script>' % jsRenderer.render()
        return '<div id="%s">%s</div>%s' % (self.prefix, contents, jsCode)

    @property
    def isStudent(self):
        owners = QueueItemOwnerCrowd(self.queueItem)
        students = LearnersCrowd(self.queueItem.section)
        return owners.contains(self.request.principal) and students.contains(self.request.principal)

    @property
    def isInstructor(self):
        instructors = InstructorsCrowd(self.queueItem.section)
        return instructors.contains(self.request.principal)

    @property
    def authorized(self):
        return self.isStudent or self.isInstructor

