#
# CanDo - Web based competency tracking system.
# Copyright (C) 2006 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
"""Competency Interfaces

$Id$
"""
__docformat__='restructuredtext'

import zope.schema
from zope.interface import Interface

from schooltool.requirement.interfaces import IRequirement, IValuesScoreSystem

from zope.i18nmessageid import MessageFactory
_ = MessageFactory('cando')


class IScoreSystemRequirement(IRequirement):
    """Any requirement with a score system."""

    scoresystem = zope.schema.Choice(
        title = _(u"Scoresystem"),
        description = _(u"The competency scoresystem."),
        vocabulary = 'cando.virginia.scoresystems',
        required = False)


class ICompetencies(IRequirement):
    """A marker interface based on IRequirement."""


class ICompetencyList(Interface):
    """An interface for an adapter which returns a list of competencies for
    ICourse, ISection or ISkillDriver."""


class ICompetency(IRequirement):
    """A simple competency."""


class ICompetencyReference(IRequirement):
    """A reference to a competency."""

    globalId = zope.schema.URI(
        title=u'Global Id',
        description=u'A unique Id of the referred competency.',
        required=True)

    id = zope.schema.TextLine(
        title = _(u"ID"),
        description = _(u"A local identifier within a course."),
        required = True)

    optionalFlag = zope.schema.Choice(
        title = _(u"Optional Flag"),
        description = _(u"Describes whether a competency is required"),
        required = True,
        values = ( _(u"required"), _(u"optional")))

    competency = zope.schema.Object(
        title = _(u"The competency"),
        schema = ICompetency,
        required = False)


class IStudentDemographics(Interface):
    """Student demographics"""

    ethnic_code = zope.schema.TextLine(
        title = _(u"Ethnic code"),
        description = _(u"A single letter ethnicity code"),
        required = False)

    ethnicity = zope.schema.TextLine(
        title = _(u"Ethnicity"),
        description = _(u"""A read-only human-readable translation of
                            the set ethnic code."""),
        required = True)

    state_report_id = zope.schema.TextLine(
        title = _(u"State report ID"),
        description = _(u"State testing number"),
        required = False)

    grade_class = zope.schema.Int(
        title = _(u"Grade class"),
        description = _(u"The grade class"),
        required = False)


class IGlobalIdUtility(Interface):
    """Utility for generating global ids unique to the current system."""

    prefix = zope.schema.URI(
        title=u'Prefix',
        description=u'The prefix to use for generated Ids on this system.',
        required=True)

    def generate(name=None, object=None):
        """generate a unique id, and take the given name and object into account."""


class IUniversalScore(Interface):
    """A score in a universal score system."""

    title = zope.schema.TextLine(
        title = _(u"Title"),
        description = _(u"A brief description of the score"),
        required = True)

    value = zope.schema.Int(
        title = _(u"Value"),
        description = _(u"The numerical value associated with the score"),
        required = True)

    weight = zope.schema.Float(
        title = _(u"Weight"),
        description = _(u"The weight given to this score, for weight GPA"),
        default=1.0,
        required=True)

    def __int__():
        """Returns the value of the score."""
    def __float__():
        """Returns the value of the score."""


class IUniversalScoreSystem(IValuesScoreSystem):
    """An extension of a simple score system."""

    scores = zope.schema.List(
        title = _(u"Scores"),
        description = _(u"The possible scores"),
        value_type = zope.schema.Object(schema = IUniversalScore),
        required = True)

    minPassingScore = zope.schema.Object(
        title = _(u"Minimum Passing Score"),
        schema = IUniversalScore,
        required = False)

    bestScore = zope.schema.Object(
        title = _(u"Best Score"),
        schema = IUniversalScore,
        required = False)

    # overrides score system description making it a Text field rather
    # than a TextLine field.
    description = zope.schema.Text(
        title = _(u"Description"),
        description = _(u"A brief description of the score system"),
        required = False)

    def addScore(score):
        """Add a score to the list of scores."""
    def removeScore(score):
        """Add a score to the list of scores."""
