from schooltool.app.interfaces import ISchoolToolApplication
from zope.publisher.browser import BrowserView
from importer import CompetencyXMLImporter
from exporter import CompetencyXMLExporter
from zope.i18nmessageid import MessageFactory
_ = MessageFactory ('cando')


class CompetencyXMLExporterEdit(BrowserView):
    
    def __init__(self, context, request):
        BrowserView.__init__(self, context, request)
        self.errors = []
        self.success = []
        self.context = context
        self.request = request
        self.exporter = CompetencyXMLExporter()
        self.update()
        

    def update(self):
        self.exporter.exportToXML(self.context)

    def __call__(self):
        return self.exporter.toPrettyXML()


class CompetencyXMLImporterEdit(BrowserView):

    __used_for__ = ISchoolToolApplication

    def __init__(self, context, request):
        BrowserView.__init__(self, context, request)
        self.errors = []
        self.success = []
        self.success.append('')
        self.context = context
        self.request = request
        self.importer = CompetencyXMLImporter(context)
        self.update()

    def update(self):
        if "UPDATE_SUBMIT" not in self.request:
            return

        charset = self.getCharset()
        if charset is None:
            return

        xmlfile = self.request.get('xmlfile', '')
        if xmlfile:
            xmlfile = xmlfile.read()

        xmltext = self.request.get('xmltext', '')

        if not xmlfile and not xmltext:
            self.errors.append(_('No data provided'))
            return

        if xmlfile:
            try:
                unicode(xmlfile, charset)
            except UnicodeError:
                self.errors.append(_('Could not convert data to Unicode'
                                     ' (incorrect charset?).'))
                return

        if xmlfile:
            ok = self.importer.importFromXML(xmlfile)
            if ok:
                self.success[0] = "XML file imported successfully."
            else:
                self.errors.append(_("Failed to import XML file"))
                self._presentErrors(self.importer.errors)

        ok = True
        if xmltext:
            self.importer.charset = None
            ok = self.importer.importFromXML(xmltext)
            if ok:
                self.success[0] = "XML text imported successfully."
            else:
                self.errors.append(_("Failed to import XML text"))
                self._presentErrors(self.importer.errors)
    
    def _presentErrors(self, err):
        """Add any errors in our ErrorCollection to the view errors.
        """
        self.errors.extend(err)

    def getCharset(self):
        """Return the charset (as a string) that was specified in the request.

        Updates self.errors and returns None if the charset was not specified
        or if it is invalid.
        """
        charset = self.request['charset']
        if charset == 'other':
            charset = self.request['other_charset']
        if not charset:
            self.errors.append(_("No charset specified"))
            return
        try:
            unicode(' ', charset)
        except LookupError:
            self.errors.append(_("Unknown charset"))
            return
        return charset
